/**
 * NetXMS - open source network management system
 * Copyright (C) 2003-2021 Victor Kirhenshtein
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.nxmc.modules.networkmaps.widgets.helpers;

import org.eclipse.gef4.zest.core.widgets.zooming.ZoomListener;
import org.eclipse.gef4.zest.core.widgets.zooming.ZoomManager;
import org.eclipse.jface.action.Action;

/**
 * Zoom action
 *
 */
public class ZoomAction extends Action implements ZoomListener
{
	private double zoomLevel;
	private ZoomManager zoomManager;
	
	/**
	 * Create zoom action for given zoom level
	 * 
	 * @param zoomLevel zoom level
	 */
	public ZoomAction(double zoomLevel, ZoomManager zoomManager)
	{
		super(Integer.toString((int)(zoomLevel * 100)) + "%", Action.AS_RADIO_BUTTON); //$NON-NLS-1$
		this.zoomLevel = zoomLevel;
		this.zoomManager = zoomManager;
		zoomManager.addZoomListener(this);
	}
	
   /**
    * @see org.eclipse.gef4.zest.core.viewers.internal.ZoomListener#zoomChanged(double)
    */
	@Override
	public void zoomChanged(double zoom)
	{
		setChecked(zoom == zoomLevel);
	}

   /**
    * @see org.eclipse.jface.action.Action#run()
    */
	@Override
	public void run()
	{
		zoomManager.setZoom(zoomLevel);
	}
}
